# civic_scraper package

## Subpackages

```{toctree}
:maxdepth: 4

civic_scraper.base
civic_scraper.platforms
```

## Submodules

## civic_scraper.cli module

```{eval-rst}
.. automodule:: civic_scraper.cli
   :members:
   :undoc-members:
   :show-inheritance:
```

## civic_scraper.runner module

```{eval-rst}
.. automodule:: civic_scraper.runner
   :members:
   :undoc-members:
   :show-inheritance:
```

## civic_scraper.utils module

```{eval-rst}
.. automodule:: civic_scraper.utils
   :members:
   :undoc-members:
   :show-inheritance:
```

## Module contents

```{eval-rst}
.. automodule:: civic_scraper
   :members:
   :undoc-members:
   :show-inheritance:
```
